@@ -37,7 +37,7 @@ no warnings;
 
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.59.00'; # our $VERSION = '';
+$VERSION = '0.59.9'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -61,6 +61,8 @@ sub descend
   @rootnames = @main::rootnames;
   %vals = %main::vals;
 
+  #@pinmediumiters = @main::pinmediumiters;
+
   $mypath = $main::mypath;
   $exeonfiles = $main::exeonfiles;
   $generatechance = $main::generatechance;
@@ -203,7 +205,7 @@ sub descend
   my $selectmixed = "$throwclean-select.csv";
 
   my $remember;
-  #if ( $direction eq "stars" ) { $remember = $winneritems[$countcase][0]; }
+  #if ( $direction eq "star" ) { $remember = $winneritems[$countcase][0]; }
 
   sub cleanselect
   {   # IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
@@ -487,12 +489,12 @@ sub descend
 
   if ( not ( $precomputed eq "") ) #NEW. TAKE CARE
   {
-    #`cp -f $repfile $weighttwo`;
     $weighttwo = $repfile;###############
   }
 
-  my $sortmixed = "$repfile-sortmixed.csv";
-  #if ($repfile) { $sortmixed = "$repfile-sortmixed.csv"; } else { die( "$!" ); } # global!
+  my $sortmixed;
+  if ($repfile) { $sortmixed = "$repfile-sortmixed.csv"; } else { die( "$!" ); }
+
   sub sortmixed
   {
     my ( $weighttwo, $sortmixed ) = @_;
@@ -502,27 +504,31 @@ sub descend
     my @lines = <WEIGHTTWO>;
     close WEIGHTTWO;
 
-    my $count = 0;
-    foreach ( @lines )
+    foreach my $line ( @lines )
     {
-      $_ = "$containernames[$count]," . "$_";
-      $count++;
+      $line =~ s/^\,+//g;
+      $line =~ s/^\s+//g;
+      $line =~ s/\,+$//g;
+      $line =~ s/\s+$//g;
+      $line =~ s/"//g;
     }
+
     say TOFILE "TAKEOPTIMA--dump(\@lines): " . dump(@lines);
 
-    my $line = $lines[0];
-    my @eltstemp = split( /,/, $line );
-    my $numberelts = scalar( @eltstemp );
-
-    #my @sorted = sort { (split(/,/, $b))[$#eltstemp] <=> (split(/,/, $a))[$#eltstemp] } @lines;
-    my @sorted = sort { ( split( /,/, $a ) )[ $#eltstemp ] <=> (split( /,/, $b ) )[ $#eltstemp ] } @lines;
+    my @sorted;
+    unless ( $direction eq "star" )
+    {
+      @sorted = sort { (split( ',', $a))[ -1 ] <=> ( split( ',', $b))[ -1 ] } @lines;
+    }
+    else
+    {
+      @sorted = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @lines;
+    }
 
     open( TOTALRES, ">>$totalres" ) or die;
 
     foreach my $line ( @sorted )
     {
-      $line =~ s/^,//;
-      $line =~ s/^\s+//;
       print SORTMIXED_ $line;
       print TOTALRES $line;
 
@@ -574,10 +580,11 @@ sub descend
     {
       $winnerentry = $lines[-1];
     }
-    elsif ( $direction eq "=" )
+    elsif ( ( $direction eq "=" ) or ( $direction eq "star" ) )
     {
-      my $half = ( int( scalar( @lines) / 2)  );
-      $winnerentry = $lines[$half];
+      my $half = ( int( scalar( @lines ) / 2 )  );
+      #$winnerentry = $lines[ $half ];
+      $winnerentry = $lines[ 1 ];
     }
     chomp $winnerentry;
 
@@ -696,7 +703,6 @@ sub descend
         }
       }
 
-
       $copy = $truewinnerline;
       $copy =~ s/$mypath\/$file//;
       @taken = Sim::OPT::extractcase( "$copy", \%mids );
@@ -712,13 +718,10 @@ sub descend
       @backvalues = ( ); #EMPTY THE CONTAINER
     }
 
-
     say $tee "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
 
-
     $countblock++; ### !!!
 
-
     # STOP CONDITION
     if ( $countblock == scalar( @blocks ) ) # NUMBER OF BLOCK OF THE CURRENT CASE
     {
@@ -733,12 +736,15 @@ sub descend
 
       say $tee "#Net number of instances: $netinstnum." ;
       open( RESPONSE , ">$mypath/response.txt" );
-      say RESPONSE "#Optimal option for case  $countcaseplus: $newtarget";
+      unless ( $direction eq "star" )
+      {
+        say RESPONSE "#Optimal option for case  $countcaseplus: $newtarget";
+      }
 
       say RESPONSE "#Net number of instances: $netinstnum.\n" ;
       say RESPONSE "Order of the parameters: " . dump( @sweeps );
       say RESPONSE "Number of parameter levels: " . dump( @varinumbers );
-      say RESPONSE "Initialization levels: " . dump( @mediumiters );
+      say RESPONSE "Last initialization levels: " . dump( @mediumiters );
       say RESPONSE "Descent directions: " . dump( $dowhat{direction} );
 
       $countblock = 0;
